@@ -1,4 +1,4 @@
-from paradoxdjango.apps import AppConfig
+from django.apps import AppConfig
 
 default_app_config = (
     "apps.explicit_default_config_without_apps.ExplicitDefaultConfigWithoutApps"
