@@ -6,17 +6,17 @@ from datetime import date
 from io import StringIO
 from unittest import mock
 
-from paradoxdjango.apps import apps
-from paradoxdjango.contrib.auth import get_permission_codename, management
-from paradoxdjango.contrib.auth.management import create_permissions, get_default_username
-from paradoxdjango.contrib.auth.management.commands import changepassword, createsuperuser
-from paradoxdjango.contrib.auth.models import Group, Permission, User
-from paradoxdjango.contrib.contenttypes.models import ContentType
-from paradoxdjango.core.management import call_command
-from paradoxdjango.core.management.base import CommandError
-from paradoxdjango.db import migrations
-from paradoxdjango.test import TestCase, override_settings
-from paradoxdjango.utils.translation import gettext_lazy as _
+from django.apps import apps
+from django.contrib.auth import get_permission_codename, management
+from django.contrib.auth.management import create_permissions, get_default_username
+from django.contrib.auth.management.commands import changepassword, createsuperuser
+from django.contrib.auth.models import Group, Permission, User
+from django.contrib.contenttypes.models import ContentType
+from django.core.management import call_command
+from django.core.management.base import CommandError
+from django.db import migrations
+from django.test import TestCase, override_settings
+from django.utils.translation import gettext_lazy as _
 
 from .models import (
     CustomUser,
@@ -152,7 +152,7 @@ class GetDefaultUsernameTestCase(TestCase):
 
 @override_settings(
     AUTH_PASSWORD_VALIDATORS=[
-        {"NAME": "paradoxdjango.contrib.auth.password_validation.NumericPasswordValidator"},
+        {"NAME": "django.contrib.auth.password_validation.NumericPasswordValidator"},
     ]
 )
 class ChangepasswordManagementCommandTestCase(TestCase):
@@ -279,7 +279,7 @@ class MultiDBChangepasswordManagementCommandTestCase(TestCase):
 @override_settings(
     SILENCED_SYSTEM_CHECKS=["fields.W342"],  # ForeignKey(unique=True)
     AUTH_PASSWORD_VALIDATORS=[
-        {"NAME": "paradoxdjango.contrib.auth.password_validation.NumericPasswordValidator"}
+        {"NAME": "django.contrib.auth.password_validation.NumericPasswordValidator"}
     ],
 )
 class CreatesuperuserManagementCommandTestCase(TestCase):
@@ -751,7 +751,7 @@ class CreatesuperuserManagementCommandTestCase(TestCase):
         AUTH_PASSWORD_VALIDATORS=[
             {
                 "NAME": (
-                    "paradoxdjango.contrib.auth.password_validation."
+                    "django.contrib.auth.password_validation."
                     "UserAttributeSimilarityValidator"
                 )
             },
@@ -799,7 +799,7 @@ class CreatesuperuserManagementCommandTestCase(TestCase):
         AUTH_PASSWORD_VALIDATORS=[
             {
                 "NAME": (
-                    "paradoxdjango.contrib.auth.password_validation."
+                    "django.contrib.auth.password_validation."
                     "UserAttributeSimilarityValidator"
                 )
             },
@@ -849,7 +849,7 @@ class CreatesuperuserManagementCommandTestCase(TestCase):
         AUTH_PASSWORD_VALIDATORS=[
             {
                 "NAME": (
-                    "paradoxdjango.contrib.auth.password_validation."
+                    "django.contrib.auth.password_validation."
                     "UserAttributeSimilarityValidator"
                 )
             },
