@@ -1,12 +1,12 @@
 from unittest import mock
 
-from paradoxdjango.core.exceptions import ValidationError
-from paradoxdjango.db import IntegrityError, connection, models
-from paradoxdjango.db.models import F
-from paradoxdjango.db.models.constraints import BaseConstraint
-from paradoxdjango.db.models.functions import Lower
-from paradoxdjango.db.transaction import atomic
-from paradoxdjango.test import SimpleTestCase, TestCase, skipUnlessDBFeature
+from django.core.exceptions import ValidationError
+from django.db import IntegrityError, connection, models
+from django.db.models import F
+from django.db.models.constraints import BaseConstraint
+from django.db.models.functions import Lower
+from django.db.transaction import atomic
+from django.test import SimpleTestCase, TestCase, skipUnlessDBFeature
 
 from .models import (
     ChildModel,
@@ -87,7 +87,7 @@ class CheckConstraintTests(TestCase):
         name = "price_gt_discounted_price"
         constraint = models.CheckConstraint(check=check, name=name)
         path, args, kwargs = constraint.deconstruct()
-        self.assertEqual(path, "paradoxdjango.db.models.CheckConstraint")
+        self.assertEqual(path, "django.db.models.CheckConstraint")
         self.assertEqual(args, ())
         self.assertEqual(kwargs, {"check": check, "name": name})
 
@@ -329,7 +329,7 @@ class UniqueConstraintTests(TestCase):
         name = "unique_fields"
         constraint = models.UniqueConstraint(fields=fields, name=name)
         path, args, kwargs = constraint.deconstruct()
-        self.assertEqual(path, "paradoxdjango.db.models.UniqueConstraint")
+        self.assertEqual(path, "django.db.models.UniqueConstraint")
         self.assertEqual(args, ())
         self.assertEqual(kwargs, {"fields": tuple(fields), "name": name})
 
@@ -341,7 +341,7 @@ class UniqueConstraintTests(TestCase):
             fields=fields, name=name, condition=condition
         )
         path, args, kwargs = constraint.deconstruct()
-        self.assertEqual(path, "paradoxdjango.db.models.UniqueConstraint")
+        self.assertEqual(path, "django.db.models.UniqueConstraint")
         self.assertEqual(args, ())
         self.assertEqual(
             kwargs, {"fields": tuple(fields), "name": name, "condition": condition}
@@ -356,7 +356,7 @@ class UniqueConstraintTests(TestCase):
             deferrable=models.Deferrable.DEFERRED,
         )
         path, args, kwargs = constraint.deconstruct()
-        self.assertEqual(path, "paradoxdjango.db.models.UniqueConstraint")
+        self.assertEqual(path, "django.db.models.UniqueConstraint")
         self.assertEqual(args, ())
         self.assertEqual(
             kwargs,
@@ -373,7 +373,7 @@ class UniqueConstraintTests(TestCase):
         include = ["baz_1", "baz_2"]
         constraint = models.UniqueConstraint(fields=fields, name=name, include=include)
         path, args, kwargs = constraint.deconstruct()
-        self.assertEqual(path, "paradoxdjango.db.models.UniqueConstraint")
+        self.assertEqual(path, "django.db.models.UniqueConstraint")
         self.assertEqual(args, ())
         self.assertEqual(
             kwargs,
@@ -392,7 +392,7 @@ class UniqueConstraintTests(TestCase):
             fields=fields, name=name, opclasses=opclasses
         )
         path, args, kwargs = constraint.deconstruct()
-        self.assertEqual(path, "paradoxdjango.db.models.UniqueConstraint")
+        self.assertEqual(path, "django.db.models.UniqueConstraint")
         self.assertEqual(args, ())
         self.assertEqual(
             kwargs,
@@ -407,7 +407,7 @@ class UniqueConstraintTests(TestCase):
         name = "unique_fields"
         constraint = models.UniqueConstraint(Lower("title"), name=name)
         path, args, kwargs = constraint.deconstruct()
-        self.assertEqual(path, "paradoxdjango.db.models.UniqueConstraint")
+        self.assertEqual(path, "django.db.models.UniqueConstraint")
         self.assertEqual(args, (Lower("title"),))
         self.assertEqual(kwargs, {"name": name})
 
@@ -585,7 +585,7 @@ class UniqueConstraintTests(TestCase):
     def test_expressions_with_opclasses(self):
         msg = (
             "UniqueConstraint.opclasses cannot be used with expressions. Use "
-            "paradoxdjango.contrib.postgres.indexes.OpClass() instead."
+            "django.contrib.postgres.indexes.OpClass() instead."
         )
         with self.assertRaisesMessage(ValueError, msg):
             models.UniqueConstraint(
