@@ -1,6 +1,6 @@
 from datetime import date
 
-from paradoxdjango.test import TestCase
+from django.test import TestCase
 
 from .models import Article
 
