@@ -12,8 +12,8 @@ try:
 except ImportError:
     pytz = None
 
-from paradoxdjango.conf import settings
-from paradoxdjango.db.models import (
+from django.conf import settings
+from django.db.models import (
     DateField,
     DateTimeField,
     F,
@@ -23,7 +23,7 @@ from paradoxdjango.db.models import (
     Subquery,
     TimeField,
 )
-from paradoxdjango.db.models.functions import (
+from django.db.models.functions import (
     Extract,
     ExtractDay,
     ExtractHour,
@@ -48,15 +48,15 @@ from paradoxdjango.db.models.functions import (
     TruncWeek,
     TruncYear,
 )
-from paradoxdjango.test import (
+from django.test import (
     TestCase,
     ignore_warnings,
     override_settings,
     skipIfDBFeature,
     skipUnlessDBFeature,
 )
-from paradoxdjango.utils import timezone
-from paradoxdjango.utils.deprecation import RemovedInDjango50Warning
+from django.utils import timezone
+from django.utils.deprecation import RemovedInDjango50Warning
 
 from ..models import Author, DTModel, Fan
 
