@@ -1,7 +1,7 @@
-from paradoxdjango.db import connection
-from paradoxdjango.db.models import Value
-from paradoxdjango.db.models.functions import Length, Repeat
-from paradoxdjango.test import TestCase
+from django.db import connection
+from django.db.models import Value
+from django.db.models.functions import Length, Repeat
+from django.test import TestCase
 
 from ..models import Author
 
