@@ -1,10 +1,10 @@
 from math import ceil
 
-from paradoxdjango.db import connection, models
-from paradoxdjango.db.models import ProtectedError, RestrictedError
-from paradoxdjango.db.models.deletion import Collector
-from paradoxdjango.db.models.sql.constants import GET_ITERATOR_CHUNK_SIZE
-from paradoxdjango.test import TestCase, skipIfDBFeature, skipUnlessDBFeature
+from django.db import connection, models
+from django.db.models import ProtectedError, RestrictedError
+from django.db.models.deletion import Collector
+from django.db.models.sql.constants import GET_ITERATOR_CHUNK_SIZE
+from django.test import TestCase, skipIfDBFeature, skipUnlessDBFeature
 
 from .models import (
     B1,
