@@ -2,8 +2,8 @@ from datetime import date
 from decimal import Decimal
 from unittest import mock
 
-from paradoxdjango.db import connection, transaction
-from paradoxdjango.db.models import (
+from django.db import connection, transaction
+from django.db.models import (
     Case,
     Count,
     DecimalField,
@@ -13,8 +13,8 @@ from paradoxdjango.db.models import (
     Sum,
     When,
 )
-from paradoxdjango.test import TestCase
-from paradoxdjango.test.testcases import skipUnlessDBFeature
+from django.test import TestCase
+from django.test.testcases import skipUnlessDBFeature
 
 from .models import (
     Author,
