@@ -1,11 +1,11 @@
 import datetime
 from operator import attrgetter
 
-from paradoxdjango.core.exceptions import FieldError
-from paradoxdjango.db import models
-from paradoxdjango.test import SimpleTestCase, TestCase, skipUnlessDBFeature
-from paradoxdjango.test.utils import isolate_apps
-from paradoxdjango.utils import translation
+from django.core.exceptions import FieldError
+from django.db import models
+from django.test import SimpleTestCase, TestCase, skipUnlessDBFeature
+from django.test.utils import isolate_apps
+from django.utils import translation
 
 from .models import (
     Article,
