@@ -2,8 +2,8 @@ import datetime
 from collections import Counter
 from unittest import mock
 
-from paradoxdjango.core.exceptions import ValidationError
-from paradoxdjango.forms import (
+from django.core.exceptions import ValidationError
+from django.forms import (
     BaseForm,
     CharField,
     DateField,
@@ -13,10 +13,10 @@ from paradoxdjango.forms import (
     SplitDateTimeField,
     formsets,
 )
-from paradoxdjango.forms.formsets import BaseFormSet, all_valid, formset_factory
-from paradoxdjango.forms.utils import ErrorList
-from paradoxdjango.forms.widgets import HiddenInput
-from paradoxdjango.test import SimpleTestCase
+from django.forms.formsets import BaseFormSet, all_valid, formset_factory
+from django.forms.utils import ErrorList
+from django.forms.widgets import HiddenInput
+from django.test import SimpleTestCase
 
 from . import jinja2_tests
 
@@ -194,8 +194,8 @@ class FormsFormsetTestCase(SimpleTestCase):
         )
 
         with mock.patch(
-            "paradoxdjango.forms.formsets.ManagementForm.is_valid", mocked_is_valid
-        ), mock.patch("paradoxdjango.forms.forms.BaseForm.full_clean", mocked_full_clean):
+            "django.forms.formsets.ManagementForm.is_valid", mocked_is_valid
+        ), mock.patch("django.forms.forms.BaseForm.full_clean", mocked_full_clean):
             self.assertTrue(formset.is_valid())
         self.assertEqual(is_valid_counter.call_count, 1)
         self.assertEqual(full_clean_counter.call_count, 4)
@@ -1413,7 +1413,7 @@ class FormsFormsetTestCase(SimpleTestCase):
         A custom renderer passed to a formset_factory() is passed to all forms
         and ErrorList.
         """
-        from paradoxdjango.forms.renderers import Jinja2
+        from django.forms.renderers import Jinja2
 
         renderer = Jinja2()
         data = {
