@@ -1,5 +1,5 @@
-from paradoxdjango import forms
-from paradoxdjango.views.generic.edit import UpdateView
+from django import forms
+from django.views.generic.edit import UpdateView
 
 from .models import Article
 
