@@ -1,15 +1,15 @@
 import os
 
-from paradoxdjango.conf import settings
-from paradoxdjango.core.exceptions import ImproperlyConfigured
-from paradoxdjango.http import HttpResponse, HttpResponsePermanentRedirect
-from paradoxdjango.middleware.locale import LocaleMiddleware
-from paradoxdjango.template import Context, Template
-from paradoxdjango.test import SimpleTestCase, override_settings
-from paradoxdjango.test.client import RequestFactory
-from paradoxdjango.test.utils import override_script_prefix
-from paradoxdjango.urls import clear_url_caches, reverse, translate_url
-from paradoxdjango.utils import translation
+from django.conf import settings
+from django.core.exceptions import ImproperlyConfigured
+from django.http import HttpResponse, HttpResponsePermanentRedirect
+from django.middleware.locale import LocaleMiddleware
+from django.template import Context, Template
+from django.test import SimpleTestCase, override_settings
+from django.test.client import RequestFactory
+from django.test.utils import override_script_prefix
+from django.urls import clear_url_caches, reverse, translate_url
+from django.utils import translation
 
 
 class PermanentRedirectLocaleMiddleWare(LocaleMiddleware):
@@ -28,17 +28,17 @@ class PermanentRedirectLocaleMiddleWare(LocaleMiddleware):
         ("pt-br", "Brazilian Portuguese"),
     ],
     MIDDLEWARE=[
-        "paradoxdjango.middleware.locale.LocaleMiddleware",
-        "paradoxdjango.middleware.common.CommonMiddleware",
+        "django.middleware.locale.LocaleMiddleware",
+        "django.middleware.common.CommonMiddleware",
     ],
     ROOT_URLCONF="i18n.patterns.urls.default",
     TEMPLATES=[
         {
-            "BACKEND": "paradoxdjango.template.backends.paradoxdjango.DjangoTemplates",
+            "BACKEND": "django.template.backends.django.DjangoTemplates",
             "DIRS": [os.path.join(os.path.dirname(__file__), "templates")],
             "OPTIONS": {
                 "context_processors": [
-                    "paradoxdjango.template.context_processors.i18n",
+                    "django.template.context_processors.i18n",
                 ],
             },
         }
@@ -268,7 +268,7 @@ class URLRedirectTests(URLTestCaseBase):
     @override_settings(
         MIDDLEWARE=[
             "i18n.patterns.tests.PermanentRedirectLocaleMiddleWare",
-            "paradoxdjango.middleware.common.CommonMiddleware",
+            "django.middleware.common.CommonMiddleware",
         ],
     )
     def test_custom_redirect_class(self):
