@@ -10,16 +10,16 @@ from unittest import mock, skipIf, skipUnless
 
 from admin_scripts.tests import AdminScriptTestCase
 
-from paradoxdjango.core import management
-from paradoxdjango.core.management import execute_from_command_line
-from paradoxdjango.core.management.base import CommandError
-from paradoxdjango.core.management.commands.makemessages import Command as MakeMessagesCommand
-from paradoxdjango.core.management.commands.makemessages import write_pot_file
-from paradoxdjango.core.management.utils import find_command
-from paradoxdjango.test import SimpleTestCase, override_settings
-from paradoxdjango.test.utils import captured_stderr, captured_stdout
-from paradoxdjango.utils._os import symlinks_supported
-from paradoxdjango.utils.translation import TranslatorCommentWarning
+from django.core import management
+from django.core.management import execute_from_command_line
+from django.core.management.base import CommandError
+from django.core.management.commands.makemessages import Command as MakeMessagesCommand
+from django.core.management.commands.makemessages import write_pot_file
+from django.core.management.utils import find_command
+from django.test import SimpleTestCase, override_settings
+from django.test.utils import captured_stderr, captured_stdout
+from django.utils._os import symlinks_supported
+from django.utils.translation import TranslatorCommentWarning
 
 from .utils import POFileAssertionMixin, RunInTmpDirMixin, copytree
 
@@ -36,7 +36,7 @@ class ExtractorTests(POFileAssertionMixin, RunInTmpDirMixin, SimpleTestCase):
 
     work_subdir = "commands"
 
-    PO_FILE = "locale/%s/LC_MESSAGES/paradoxdjango.po" % LOCALE
+    PO_FILE = "locale/%s/LC_MESSAGES/django.po" % LOCALE
 
     def _run_makemessages(self, **options):
         out = StringIO()
@@ -106,9 +106,9 @@ class ExtractorTests(POFileAssertionMixin, RunInTmpDirMixin, SimpleTestCase):
 
     def assertLocationCommentPresent(self, po_filename, line_number, *comment_parts):
         r"""
-        self.assertLocationCommentPresent('paradoxdjango.po', 42, 'dirA', 'dirB', 'foo.py')
+        self.assertLocationCommentPresent('django.po', 42, 'dirA', 'dirB', 'foo.py')
 
-        verifies that the paradoxdjango.po file has a gettext-style location comment
+        verifies that the django.po file has a gettext-style location comment
         of the form
 
         `#: dirA/dirB/foo.py:42`
@@ -162,7 +162,7 @@ class BasicExtractorTests(ExtractorTests):
         # One of either the --locale, --exclude, or --all options is required.
         msg = "Type 'manage.py help makemessages' for usage information."
         with mock.patch(
-            "paradoxdjango.core.management.commands.makemessages.sys.argv",
+            "django.core.management.commands.makemessages.sys.argv",
             ["manage.py", "makemessages"],
         ):
             with self.assertRaisesRegex(CommandError, msg):
@@ -182,7 +182,7 @@ class BasicExtractorTests(ExtractorTests):
         )
         self.assertIn("invalid locale pl-PL, did you mean pl_PL?", out.getvalue())
         self.assertNotIn("processing locale pl-PL", out.getvalue())
-        self.assertIs(Path("locale/pl-PL/LC_MESSAGES/paradoxdjango.po").exists(), False)
+        self.assertIs(Path("locale/pl-PL/LC_MESSAGES/django.po").exists(), False)
 
     def test_comments_extractor(self):
         management.call_command("makemessages", locale=[LOCALE], verbosity=0)
@@ -425,7 +425,7 @@ class BasicExtractorTests(ExtractorTests):
         cmd = MakeMessagesCommand()
         cmd.ignore_patterns = ["CVS", ".*", "*~", "*.pyc"]
         cmd.symlinks = False
-        cmd.domain = "paradoxdjango"
+        cmd.domain = "django"
         cmd.extensions = ["html", "txt", "py"]
         cmd.verbosity = 0
         cmd.locale_paths = []
@@ -440,7 +440,7 @@ class BasicExtractorTests(ExtractorTests):
         found_exts = {os.path.splitext(tfile.file)[1] for tfile in found_files}
         self.assertEqual(found_exts.difference({".js"}), set())
 
-    @mock.patch("paradoxdjango.core.management.commands.makemessages.popen_wrapper")
+    @mock.patch("django.core.management.commands.makemessages.popen_wrapper")
     def test_makemessages_gettext_version(self, mocked_popen_wrapper):
         # "Normal" output:
         mocked_popen_wrapper.return_value = (
@@ -479,7 +479,7 @@ class BasicExtractorTests(ExtractorTests):
         Update of PO file doesn't corrupt it with non-UTF-8 encoding on Windows
         (#23271).
         """
-        BR_PO_BASE = "locale/pt_BR/LC_MESSAGES/paradoxdjango"
+        BR_PO_BASE = "locale/pt_BR/LC_MESSAGES/django"
         shutil.copyfile(BR_PO_BASE + ".pristine", BR_PO_BASE + ".po")
         management.call_command("makemessages", locale=["pt_BR"], verbosity=0)
         self.assertTrue(os.path.exists(BR_PO_BASE + ".po"))
@@ -623,7 +623,7 @@ class SymlinkExtractorTests(ExtractorTests):
 
 class CopyPluralFormsExtractorTests(ExtractorTests):
 
-    PO_FILE_ES = "locale/es/LC_MESSAGES/paradoxdjango.po"
+    PO_FILE_ES = "locale/es/LC_MESSAGES/django.po"
 
     def test_copy_plural_forms(self):
         management.call_command("makemessages", locale=[LOCALE], verbosity=0)
@@ -660,7 +660,7 @@ class CopyPluralFormsExtractorTests(ExtractorTests):
         with open(self.PO_FILE) as fp:
             po_contents = fp.read()
             self.assertNotIn(
-                "#-#-#-#-#  paradoxdjango.pot (PACKAGE VERSION)  #-#-#-#-#\\n", po_contents
+                "#-#-#-#-#  django.pot (PACKAGE VERSION)  #-#-#-#-#\\n", po_contents
             )
             self.assertMsgId(
                 "First `translate`, then `blocktranslate` with a plural", po_contents
@@ -769,7 +769,7 @@ class LocationCommentsTests(ExtractorTests):
         self.assertLocationCommentNotPresent(self.PO_FILE, None, "test.html")
 
     @mock.patch(
-        "paradoxdjango.core.management.commands.makemessages.Command.gettext_version",
+        "django.core.management.commands.makemessages.Command.gettext_version",
         new=(0, 18, 99),
     )
     def test_add_location_gettext_version_check(self):
@@ -789,7 +789,7 @@ class LocationCommentsTests(ExtractorTests):
 
 class KeepPotFileExtractorTests(ExtractorTests):
 
-    POT_FILE = "locale/paradoxdjango.pot"
+    POT_FILE = "locale/django.pot"
 
     def test_keep_pot_disabled_by_default(self):
         management.call_command("makemessages", locale=[LOCALE], verbosity=0)
@@ -809,9 +809,9 @@ class KeepPotFileExtractorTests(ExtractorTests):
 
 
 class MultipleLocaleExtractionTests(ExtractorTests):
-    PO_FILE_PT = "locale/pt/LC_MESSAGES/paradoxdjango.po"
-    PO_FILE_DE = "locale/de/LC_MESSAGES/paradoxdjango.po"
-    PO_FILE_KO = "locale/ko/LC_MESSAGES/paradoxdjango.po"
+    PO_FILE_PT = "locale/pt/LC_MESSAGES/django.po"
+    PO_FILE_DE = "locale/de/LC_MESSAGES/django.po"
+    PO_FILE_KO = "locale/ko/LC_MESSAGES/django.po"
     LOCALES = ["pt", "de", "ch"]
 
     def test_multiple_locales(self):
@@ -829,7 +829,7 @@ class MultipleLocaleExtractionTests(ExtractorTests):
         # Excluding locales that do not compile
         management.call_command("makemessages", exclude=["ja", "es_AR"], verbosity=0)
         self.assertTrue(os.path.exists(self.PO_FILE_KO))
-        self.assertFalse(os.path.exists("locale/_do_not_pick/LC_MESSAGES/paradoxdjango.po"))
+        self.assertFalse(os.path.exists("locale/_do_not_pick/LC_MESSAGES/django.po"))
 
 
 class ExcludedLocaleExtractionTests(ExtractorTests):
@@ -837,7 +837,7 @@ class ExcludedLocaleExtractionTests(ExtractorTests):
     work_subdir = "exclude"
 
     LOCALES = ["en", "fr", "it"]
-    PO_FILE = "locale/%s/LC_MESSAGES/paradoxdjango.po"
+    PO_FILE = "locale/%s/LC_MESSAGES/django.po"
 
     def _set_times_for_all_po_files(self):
         """
@@ -856,7 +856,7 @@ class ExcludedLocaleExtractionTests(ExtractorTests):
             # `call_command` bypasses the parser; by calling
             # `execute_from_command_line` with the help subcommand we
             # ensure that there are no issues with the parser itself.
-            execute_from_command_line(["paradoxdjango-admin", "help", "makemessages"])
+            execute_from_command_line(["django-admin", "help", "makemessages"])
 
     def test_one_locale_excluded(self):
         management.call_command("makemessages", exclude=["it"], verbosity=0)
@@ -894,7 +894,7 @@ class CustomLayoutExtractionTests(ExtractorTests):
     def test_no_locale_raises(self):
         msg = (
             "Unable to find a locale path to store translations for file "
-            "manage.py-tpl. Make sure the 'locale' directory exists in an app "
+            "__init__.py. Make sure the 'locale' directory exists in an app "
             "or LOCALE_PATHS setting is set."
         )
         with self.assertRaisesMessage(management.CommandError, msg):
@@ -916,7 +916,7 @@ class CustomLayoutExtractionTests(ExtractorTests):
         with override_settings(LOCALE_PATHS=[locale_path]):
             management.call_command("makemessages", locale=[LOCALE], verbosity=0)
             project_de_locale = os.path.join(
-                self.test_dir, "project_locale", "de", "LC_MESSAGES", "paradoxdjango.po"
+                self.test_dir, "project_locale", "de", "LC_MESSAGES", "django.po"
             )
             app_de_locale = os.path.join(
                 self.test_dir,
@@ -924,7 +924,7 @@ class CustomLayoutExtractionTests(ExtractorTests):
                 "locale",
                 "de",
                 "LC_MESSAGES",
-                "paradoxdjango.po",
+                "django.po",
             )
             self.assertTrue(os.path.exists(project_de_locale))
             self.assertTrue(os.path.exists(app_de_locale))
