@@ -4,15 +4,15 @@ from io import StringIO
 
 from admin_scripts.tests import AdminScriptTestCase
 
-from paradoxdjango.conf import settings
-from paradoxdjango.core import mail
-from paradoxdjango.core.exceptions import PermissionDenied
-from paradoxdjango.core.files.temp import NamedTemporaryFile
-from paradoxdjango.core.management import color
-from paradoxdjango.http.multipartparser import MultiPartParserError
-from paradoxdjango.test import RequestFactory, SimpleTestCase, override_settings
-from paradoxdjango.test.utils import LoggingCaptureMixin
-from paradoxdjango.utils.log import (
+from django.conf import settings
+from django.core import mail
+from django.core.exceptions import PermissionDenied
+from django.core.files.temp import NamedTemporaryFile
+from django.core.management import color
+from django.http.multipartparser import MultiPartParserError
+from django.test import RequestFactory, SimpleTestCase, override_settings
+from django.test.utils import LoggingCaptureMixin
+from django.utils.log import (
     DEFAULT_LOGGING,
     AdminEmailHandler,
     CallbackFilter,
@@ -20,7 +20,7 @@ from paradoxdjango.utils.log import (
     RequireDebugTrue,
     ServerFormatter,
 )
-from paradoxdjango.views.debug import ExceptionReporter
+from django.views.debug import ExceptionReporter
 
 from . import views
 from .logconfig import MyEmailBackend
@@ -65,7 +65,7 @@ class DefaultLoggingTests(
 ):
     def test_django_logger(self):
         """
-        The 'paradoxdjango' base logger only output anything when DEBUG=True.
+        The 'django' base logger only output anything when DEBUG=True.
         """
         self.logger.error("Hey, this is an error.")
         self.assertEqual(self.logger_output.getvalue(), "")
@@ -92,7 +92,7 @@ class DefaultLoggingTests(
 
 class LoggingAssertionMixin:
     def assertLogsRequest(
-        self, url, level, msg, status_code, logger="paradoxdjango.request", exc_class=None
+        self, url, level, msg, status_code, logger="django.request", exc_class=None
     ):
         with self.assertLogs(logger, level) as cm:
             try:
@@ -189,8 +189,8 @@ class HandlerLoggingTests(
     USE_I18N=True,
     LANGUAGES=[("en", "English")],
     MIDDLEWARE=[
-        "paradoxdjango.middleware.locale.LocaleMiddleware",
-        "paradoxdjango.middleware.common.CommonMiddleware",
+        "django.middleware.locale.LocaleMiddleware",
+        "django.middleware.common.CommonMiddleware",
     ],
     ROOT_URLCONF="logging_tests.urls_i18n",
 )
@@ -232,7 +232,7 @@ class CallbackFilterTest(SimpleTestCase):
 
 
 class AdminEmailHandlerTest(SimpleTestCase):
-    logger = logging.getLogger("paradoxdjango")
+    logger = logging.getLogger("django")
     request_factory = RequestFactory()
 
     def get_admin_email_handler(self, logger):
@@ -506,11 +506,11 @@ dictConfig.called = False
 
 class SetupConfigureLogging(SimpleTestCase):
     """
-    Calling paradoxdjango.setup() initializes the logging configuration.
+    Calling django.setup() initializes the logging configuration.
     """
 
     def test_configure_initializes_logging(self):
-        from paradoxdjango import setup
+        from django import setup
 
         try:
             with override_settings(
@@ -531,7 +531,7 @@ class SecurityLoggerTest(LoggingAssertionMixin, SimpleTestCase):
             level="ERROR",
             msg="dubious",
             status_code=400,
-            logger="paradoxdjango.security.SuspiciousOperation",
+            logger="django.security.SuspiciousOperation",
         )
 
     def test_suspicious_operation_uses_sublogger(self):
@@ -540,7 +540,7 @@ class SecurityLoggerTest(LoggingAssertionMixin, SimpleTestCase):
             level="ERROR",
             msg="dubious",
             status_code=400,
-            logger="paradoxdjango.security.DisallowedHost",
+            logger="django.security.DisallowedHost",
         )
 
     @override_settings(
@@ -623,7 +623,7 @@ class LogFormattersTests(SimpleTestCase):
     def test_server_formatter_default_format(self):
         server_time = "2016-09-25 10:20:30"
         log_msg = "log message"
-        logger = logging.getLogger("paradoxdjango.server")
+        logger = logging.getLogger("django.server")
 
         @contextmanager
         def patch_django_server_logger():
