@@ -3,9 +3,9 @@ from datetime import datetime
 from math import ceil
 from operator import attrgetter
 
-from paradoxdjango.core.exceptions import FieldError
-from paradoxdjango.db import connection, models
-from paradoxdjango.db.models import (
+from django.core.exceptions import FieldError
+from django.db import connection, models
+from django.db.models import (
     BooleanField,
     Case,
     Exists,
@@ -18,16 +18,16 @@ from paradoxdjango.db.models import (
     Value,
     When,
 )
-from paradoxdjango.db.models.functions import Cast, Substr
-from paradoxdjango.db.models.lookups import (
+from django.db.models.functions import Cast, Substr
+from django.db.models.lookups import (
     Exact,
     GreaterThan,
     GreaterThanOrEqual,
     LessThan,
     LessThanOrEqual,
 )
-from paradoxdjango.test import TestCase, skipUnlessDBFeature
-from paradoxdjango.test.utils import isolate_apps
+from django.test import TestCase, skipUnlessDBFeature
+from django.test.utils import isolate_apps
 
 from .models import (
     Article,
