@@ -1,7 +1,7 @@
 from unittest import mock
 
-from paradoxdjango.db import transaction
-from paradoxdjango.test import TestCase, skipIfDBFeature, skipUnlessDBFeature
+from django.db import transaction
+from django.test import TestCase, skipIfDBFeature, skipUnlessDBFeature
 
 from .models import Article, InheritedArticleA, InheritedArticleB, Publication, User
 
