@@ -1,4 +1,4 @@
-from paradoxdjango.db import migrations, models
+from django.db import migrations, models
 
 
 class Migration(migrations.Migration):
