@@ -1,4 +1,4 @@
-from paradoxdjango.db import migrations
+from django.db import migrations
 
 
 class Migration(migrations.Migration):
