@@ -2,11 +2,11 @@ import operator
 import uuid
 from unittest import mock
 
-from paradoxdjango import forms
-from paradoxdjango.core import serializers
-from paradoxdjango.core.exceptions import ValidationError
-from paradoxdjango.core.serializers.json import DjangoJSONEncoder
-from paradoxdjango.db import (
+from django import forms
+from django.core import serializers
+from django.core.exceptions import ValidationError
+from django.core.serializers.json import DjangoJSONEncoder
+from django.db import (
     DataError,
     IntegrityError,
     NotSupportedError,
@@ -14,7 +14,7 @@ from paradoxdjango.db import (
     connection,
     models,
 )
-from paradoxdjango.db.models import (
+from django.db.models import (
     Count,
     ExpressionWrapper,
     F,
@@ -25,16 +25,16 @@ from paradoxdjango.db.models import (
     Transform,
     Value,
 )
-from paradoxdjango.db.models.expressions import RawSQL
-from paradoxdjango.db.models.fields.json import (
+from django.db.models.expressions import RawSQL
+from django.db.models.fields.json import (
     KeyTextTransform,
     KeyTransform,
     KeyTransformFactory,
     KeyTransformTextLookupMixin,
 )
-from paradoxdjango.db.models.functions import Cast
-from paradoxdjango.test import SimpleTestCase, TestCase, skipIfDBFeature, skipUnlessDBFeature
-from paradoxdjango.test.utils import CaptureQueriesContext
+from django.db.models.functions import Cast
+from django.test import SimpleTestCase, TestCase, skipIfDBFeature, skipUnlessDBFeature
+from django.test.utils import CaptureQueriesContext
 
 from .models import CustomJSONDecoder, JSONModel, NullableJSONModel, RelatedJSONModel
 
@@ -69,7 +69,7 @@ class TestMethods(SimpleTestCase):
     def test_deconstruct(self):
         field = models.JSONField()
         name, path, args, kwargs = field.deconstruct()
-        self.assertEqual(path, "paradoxdjango.db.models.JSONField")
+        self.assertEqual(path, "django.db.models.JSONField")
         self.assertEqual(args, [])
         self.assertEqual(kwargs, {})
 
@@ -169,10 +169,10 @@ class TestSerialization(SimpleTestCase):
 
     def test_xml_serialization(self):
         test_xml_data = (
-            '<paradoxdjango-objects version="1.0">'
+            '<django-objects version="1.0">'
             '<object model="model_fields.nullablejsonmodel">'
             '<field name="value" type="JSONField">%s'
-            "</field></object></paradoxdjango-objects>"
+            "</field></object></django-objects>"
         )
         for value, serialized in self.test_values:
             with self.subTest(value=value):
