@@ -1,9 +1,9 @@
 import datetime
 from unittest import mock
 
-from paradoxdjango.contrib.postgres.indexes import OpClass
-from paradoxdjango.db import IntegrityError, NotSupportedError, connection, transaction
-from paradoxdjango.db.models import (
+from django.contrib.postgres.indexes import OpClass
+from django.db import IntegrityError, NotSupportedError, connection, transaction
+from django.db.models import (
     CheckConstraint,
     Deferrable,
     F,
@@ -12,10 +12,10 @@ from paradoxdjango.db.models import (
     Q,
     UniqueConstraint,
 )
-from paradoxdjango.db.models.fields.json import KeyTextTransform
-from paradoxdjango.db.models.functions import Cast, Left, Lower
-from paradoxdjango.test import modify_settings, skipUnlessDBFeature
-from paradoxdjango.utils import timezone
+from django.db.models.fields.json import KeyTextTransform
+from django.db.models.functions import Cast, Left, Lower
+from django.test import modify_settings, skipUnlessDBFeature
+from django.utils import timezone
 
 from . import PostgreSQLTestCase
 from .models import HotelReservation, IntegerArrayModel, RangesModel, Room, Scene
@@ -23,8 +23,8 @@ from .models import HotelReservation, IntegerArrayModel, RangesModel, Room, Scen
 try:
     from psycopg2.extras import DateRange, NumericRange
 
-    from paradoxdjango.contrib.postgres.constraints import ExclusionConstraint
-    from paradoxdjango.contrib.postgres.fields import (
+    from django.contrib.postgres.constraints import ExclusionConstraint
+    from django.contrib.postgres.fields import (
         DateTimeRangeField,
         RangeBoundary,
         RangeOperators,
@@ -33,7 +33,7 @@ except ImportError:
     pass
 
 
-@modify_settings(INSTALLED_APPS={"append": "paradoxdjango.contrib.postgres"})
+@modify_settings(INSTALLED_APPS={"append": "django.contrib.postgres"})
 class SchemaTests(PostgreSQLTestCase):
     get_opclass_query = """
         SELECT opcname, c.relname FROM pg_opclass AS oc
@@ -469,7 +469,7 @@ class ExclusionConstraintTests(PostgreSQLTestCase):
         )
         path, args, kwargs = constraint.deconstruct()
         self.assertEqual(
-            path, "paradoxdjango.contrib.postgres.constraints.ExclusionConstraint"
+            path, "django.contrib.postgres.constraints.ExclusionConstraint"
         )
         self.assertEqual(args, ())
         self.assertEqual(
@@ -494,7 +494,7 @@ class ExclusionConstraintTests(PostgreSQLTestCase):
         )
         path, args, kwargs = constraint.deconstruct()
         self.assertEqual(
-            path, "paradoxdjango.contrib.postgres.constraints.ExclusionConstraint"
+            path, "django.contrib.postgres.constraints.ExclusionConstraint"
         )
         self.assertEqual(args, ())
         self.assertEqual(
@@ -520,7 +520,7 @@ class ExclusionConstraintTests(PostgreSQLTestCase):
         )
         path, args, kwargs = constraint.deconstruct()
         self.assertEqual(
-            path, "paradoxdjango.contrib.postgres.constraints.ExclusionConstraint"
+            path, "django.contrib.postgres.constraints.ExclusionConstraint"
         )
         self.assertEqual(args, ())
         self.assertEqual(
@@ -543,7 +543,7 @@ class ExclusionConstraintTests(PostgreSQLTestCase):
         )
         path, args, kwargs = constraint.deconstruct()
         self.assertEqual(
-            path, "paradoxdjango.contrib.postgres.constraints.ExclusionConstraint"
+            path, "django.contrib.postgres.constraints.ExclusionConstraint"
         )
         self.assertEqual(args, ())
         self.assertEqual(
@@ -563,7 +563,7 @@ class ExclusionConstraintTests(PostgreSQLTestCase):
         )
         path, args, kwargs = constraint.deconstruct()
         self.assertEqual(
-            path, "paradoxdjango.contrib.postgres.constraints.ExclusionConstraint"
+            path, "django.contrib.postgres.constraints.ExclusionConstraint"
         )
         self.assertEqual(args, ())
         self.assertEqual(
@@ -583,7 +583,7 @@ class ExclusionConstraintTests(PostgreSQLTestCase):
         )
         path, args, kwargs = constraint.deconstruct()
         self.assertEqual(
-            path, "paradoxdjango.contrib.postgres.constraints.ExclusionConstraint"
+            path, "django.contrib.postgres.constraints.ExclusionConstraint"
         )
         self.assertEqual(args, ())
         self.assertEqual(
@@ -843,7 +843,7 @@ class ExclusionConstraintTests(PostgreSQLTestCase):
         msg = "Covering exclusion constraints requires PostgreSQL 12+."
         with connection.schema_editor() as editor:
             with mock.patch(
-                "paradoxdjango.db.backends.postgresql.features.DatabaseFeatures."
+                "django.db.backends.postgresql.features.DatabaseFeatures."
                 "supports_covering_gist_indexes",
                 False,
             ):
