@@ -1,6 +1,6 @@
 from unittest import mock
 
-from paradoxdjango.contrib.postgres.indexes import (
+from django.contrib.postgres.indexes import (
     BloomIndex,
     BrinIndex,
     BTreeIndex,
@@ -10,11 +10,11 @@ from paradoxdjango.contrib.postgres.indexes import (
     OpClass,
     SpGistIndex,
 )
-from paradoxdjango.db import NotSupportedError, connection
-from paradoxdjango.db.models import CharField, F, Index, Q
-from paradoxdjango.db.models.functions import Cast, Collate, Length, Lower
-from paradoxdjango.test import skipUnlessDBFeature
-from paradoxdjango.test.utils import modify_settings, register_lookup
+from django.db import NotSupportedError, connection
+from django.db.models import CharField, F, Index, Q
+from django.db.models.functions import Cast, Collate, Length, Lower
+from django.test import skipUnlessDBFeature
+from django.test.utils import modify_settings, register_lookup
 
 from . import PostgreSQLSimpleTestCase, PostgreSQLTestCase
 from .fields import SearchVector, SearchVectorField
@@ -35,7 +35,7 @@ class IndexTestMixin:
         )
         path, args, kwargs = index.deconstruct()
         self.assertEqual(
-            path, "paradoxdjango.contrib.postgres.indexes.%s" % self.index_class.__name__
+            path, "django.contrib.postgres.indexes.%s" % self.index_class.__name__
         )
         self.assertEqual(args, ())
         self.assertEqual(
@@ -49,7 +49,7 @@ class IndexTestMixin:
         path, args, kwargs = index.deconstruct()
         self.assertEqual(
             path,
-            f"paradoxdjango.contrib.postgres.indexes.{self.index_class.__name__}",
+            f"django.contrib.postgres.indexes.{self.index_class.__name__}",
         )
         self.assertEqual(args, (Lower("title"),))
         self.assertEqual(kwargs, {"name": name})
@@ -64,7 +64,7 @@ class BloomIndexTests(IndexTestMixin, PostgreSQLSimpleTestCase):
     def test_deconstruction(self):
         index = BloomIndex(fields=["title"], name="test_bloom", length=80, columns=[4])
         path, args, kwargs = index.deconstruct()
-        self.assertEqual(path, "paradoxdjango.contrib.postgres.indexes.BloomIndex")
+        self.assertEqual(path, "django.contrib.postgres.indexes.BloomIndex")
         self.assertEqual(args, ())
         self.assertEqual(
             kwargs,
@@ -116,7 +116,7 @@ class BrinIndexTests(IndexTestMixin, PostgreSQLSimpleTestCase):
             pages_per_range=16,
         )
         path, args, kwargs = index.deconstruct()
-        self.assertEqual(path, "paradoxdjango.contrib.postgres.indexes.BrinIndex")
+        self.assertEqual(path, "django.contrib.postgres.indexes.BrinIndex")
         self.assertEqual(args, ())
         self.assertEqual(
             kwargs,
@@ -144,7 +144,7 @@ class BTreeIndexTests(IndexTestMixin, PostgreSQLSimpleTestCase):
     def test_deconstruction(self):
         index = BTreeIndex(fields=["title"], name="test_title_btree", fillfactor=80)
         path, args, kwargs = index.deconstruct()
-        self.assertEqual(path, "paradoxdjango.contrib.postgres.indexes.BTreeIndex")
+        self.assertEqual(path, "django.contrib.postgres.indexes.BTreeIndex")
         self.assertEqual(args, ())
         self.assertEqual(
             kwargs, {"fields": ["title"], "name": "test_title_btree", "fillfactor": 80}
@@ -165,7 +165,7 @@ class GinIndexTests(IndexTestMixin, PostgreSQLSimpleTestCase):
             gin_pending_list_limit=128,
         )
         path, args, kwargs = index.deconstruct()
-        self.assertEqual(path, "paradoxdjango.contrib.postgres.indexes.GinIndex")
+        self.assertEqual(path, "django.contrib.postgres.indexes.GinIndex")
         self.assertEqual(args, ())
         self.assertEqual(
             kwargs,
@@ -189,7 +189,7 @@ class GistIndexTests(IndexTestMixin, PostgreSQLSimpleTestCase):
             fields=["title"], name="test_title_gist", buffering=False, fillfactor=80
         )
         path, args, kwargs = index.deconstruct()
-        self.assertEqual(path, "paradoxdjango.contrib.postgres.indexes.GistIndex")
+        self.assertEqual(path, "django.contrib.postgres.indexes.GistIndex")
         self.assertEqual(args, ())
         self.assertEqual(
             kwargs,
@@ -211,7 +211,7 @@ class HashIndexTests(IndexTestMixin, PostgreSQLSimpleTestCase):
     def test_deconstruction(self):
         index = HashIndex(fields=["title"], name="test_title_hash", fillfactor=80)
         path, args, kwargs = index.deconstruct()
-        self.assertEqual(path, "paradoxdjango.contrib.postgres.indexes.HashIndex")
+        self.assertEqual(path, "django.contrib.postgres.indexes.HashIndex")
         self.assertEqual(args, ())
         self.assertEqual(
             kwargs, {"fields": ["title"], "name": "test_title_hash", "fillfactor": 80}
@@ -227,14 +227,14 @@ class SpGistIndexTests(IndexTestMixin, PostgreSQLSimpleTestCase):
     def test_deconstruction(self):
         index = SpGistIndex(fields=["title"], name="test_title_spgist", fillfactor=80)
         path, args, kwargs = index.deconstruct()
-        self.assertEqual(path, "paradoxdjango.contrib.postgres.indexes.SpGistIndex")
+        self.assertEqual(path, "django.contrib.postgres.indexes.SpGistIndex")
         self.assertEqual(args, ())
         self.assertEqual(
             kwargs, {"fields": ["title"], "name": "test_title_spgist", "fillfactor": 80}
         )
 
 
-@modify_settings(INSTALLED_APPS={"append": "paradoxdjango.contrib.postgres"})
+@modify_settings(INSTALLED_APPS={"append": "django.contrib.postgres"})
 class SchemaTests(PostgreSQLTestCase):
     get_opclass_query = """
         SELECT opcname, c.relname FROM pg_opclass AS oc
@@ -519,7 +519,7 @@ class SchemaTests(PostgreSQLTestCase):
         msg = "Covering GiST indexes requires PostgreSQL 12+."
         with self.assertRaisesMessage(NotSupportedError, msg):
             with mock.patch(
-                "paradoxdjango.db.backends.postgresql.features.DatabaseFeatures."
+                "django.db.backends.postgresql.features.DatabaseFeatures."
                 "supports_covering_gist_indexes",
                 False,
             ):
