@@ -1,4 +1,4 @@
-from paradoxdjango.test import TestCase
+from django.test import TestCase
 
 from .models import Person
 
