@@ -13,24 +13,24 @@ import warnings
 from pathlib import Path
 
 try:
-    import paradoxdjango
+    import django
 except ImportError as e:
     raise RuntimeError(
         "Django module not found, reference tests/README.rst for instructions."
     ) from e
 else:
-    from paradoxdjango.apps import apps
-    from paradoxdjango.conf import settings
-    from paradoxdjango.db import connection, connections
-    from paradoxdjango.test import TestCase, TransactionTestCase
-    from paradoxdjango.test.runner import get_max_test_processes, parallel_type
-    from paradoxdjango.test.selenium import SeleniumTestCaseBase
-    from paradoxdjango.test.utils import NullTimeKeeper, TimeKeeper, get_runner
-    from paradoxdjango.utils.deprecation import (
+    from django.apps import apps
+    from django.conf import settings
+    from django.db import connection, connections
+    from django.test import TestCase, TransactionTestCase
+    from django.test.runner import get_max_test_processes, parallel_type
+    from django.test.selenium import SeleniumTestCaseBase
+    from django.test.utils import NullTimeKeeper, TimeKeeper, get_runner
+    from django.utils.deprecation import (
         RemovedInDjango41Warning,
         RemovedInDjango50Warning,
     )
-    from paradoxdjango.utils.log import DEFAULT_LOGGING
+    from django.utils.log import DEFAULT_LOGGING
 
 try:
     import MySQLdb
@@ -87,30 +87,30 @@ SUBDIRS_TO_SKIP = {
 }
 
 ALWAYS_INSTALLED_APPS = [
-    "paradoxdjango.contrib.contenttypes",
-    "paradoxdjango.contrib.auth",
-    "paradoxdjango.contrib.sites",
-    "paradoxdjango.contrib.sessions",
-    "paradoxdjango.contrib.messages",
-    "paradoxdjango.contrib.admin.apps.SimpleAdminConfig",
-    "paradoxdjango.contrib.staticfiles",
+    "django.contrib.contenttypes",
+    "django.contrib.auth",
+    "django.contrib.sites",
+    "django.contrib.sessions",
+    "django.contrib.messages",
+    "django.contrib.admin.apps.SimpleAdminConfig",
+    "django.contrib.staticfiles",
 ]
 
 ALWAYS_MIDDLEWARE = [
-    "paradoxdjango.contrib.sessions.middleware.SessionMiddleware",
-    "paradoxdjango.middleware.common.CommonMiddleware",
-    "paradoxdjango.middleware.csrf.CsrfViewMiddleware",
-    "paradoxdjango.contrib.auth.middleware.AuthenticationMiddleware",
-    "paradoxdjango.contrib.messages.middleware.MessageMiddleware",
+    "django.contrib.sessions.middleware.SessionMiddleware",
+    "django.middleware.common.CommonMiddleware",
+    "django.middleware.csrf.CsrfViewMiddleware",
+    "django.contrib.auth.middleware.AuthenticationMiddleware",
+    "django.contrib.messages.middleware.MessageMiddleware",
 ]
 
 # Need to add the associated contrib app to INSTALLED_APPS in some cases to
 # avoid "RuntimeError: Model class X doesn't declare an explicit app_label
 # and isn't in an application in INSTALLED_APPS."
 CONTRIB_TESTS_TO_APPS = {
-    "deprecation": ["paradoxdjango.contrib.flatpages", "paradoxdjango.contrib.redirects"],
-    "flatpages_tests": ["paradoxdjango.contrib.flatpages"],
-    "redirects_tests": ["paradoxdjango.contrib.redirects"],
+    "deprecation": ["django.contrib.flatpages", "django.contrib.redirects"],
+    "flatpages_tests": ["django.contrib.flatpages"],
+    "redirects_tests": ["django.contrib.redirects"],
 }
 
 
@@ -137,7 +137,7 @@ def get_test_modules(gis_enabled):
                     "." in f.name
                     or os.path.basename(f.name) in subdirs_to_skip
                     or f.is_file()
-                    or not os.path.exists(os.path.join(f.path, "manage.py-tpl"))
+                    or not os.path.exists(os.path.join(f.path, "__init__.py"))
                 ):
                     continue
                 test_module = f.name
@@ -172,7 +172,7 @@ def get_filtered_test_modules(start_at, start_after, gis_enabled, test_labels=No
         label_modules.add(test_module)
 
     # It would be nice to put this validation earlier but it must come after
-    # paradoxdjango.setup() so that connection.features.gis_enabled can be accessed.
+    # django.setup() so that connection.features.gis_enabled can be accessed.
     if "gis_tests" in label_modules and not gis_enabled:
         print("Aborting: A GIS database backend is required to run gis_tests.")
         sys.exit(1)
@@ -218,15 +218,15 @@ def setup_collect_tests(start_at, start_after, test_labels=None):
     settings.STATIC_ROOT = os.path.join(TMPDIR, "static")
     settings.TEMPLATES = [
         {
-            "BACKEND": "paradoxdjango.template.backends.paradoxdjango.DjangoTemplates",
+            "BACKEND": "django.template.backends.django.DjangoTemplates",
             "DIRS": [TEMPLATE_DIR],
             "APP_DIRS": True,
             "OPTIONS": {
                 "context_processors": [
-                    "paradoxdjango.template.context_processors.debug",
-                    "paradoxdjango.template.context_processors.request",
-                    "paradoxdjango.contrib.auth.context_processors.auth",
-                    "paradoxdjango.contrib.messages.context_processors.messages",
+                    "django.template.context_processors.debug",
+                    "django.template.context_processors.request",
+                    "django.contrib.auth.context_processors.auth",
+                    "django.contrib.messages.context_processors.messages",
                 ],
             },
         }
@@ -244,16 +244,16 @@ def setup_collect_tests(start_at, start_after, test_labels=None):
     log_config = copy.deepcopy(DEFAULT_LOGGING)
     # Filter out non-error logging so we don't have to capture it in lots of
     # tests.
-    log_config["loggers"]["paradoxdjango"]["level"] = "ERROR"
+    log_config["loggers"]["django"]["level"] = "ERROR"
     settings.LOGGING = log_config
     settings.SILENCED_SYSTEM_CHECKS = [
         "fields.W342",  # ForeignKey(unique=True) -> OneToOneField
     ]
 
     # Load all the ALWAYS_INSTALLED_APPS.
-    paradoxdjango.setup()
+    django.setup()
 
-    # This flag must be evaluated after paradoxdjango.setup() because otherwise it can
+    # This flag must be evaluated after django.setup() because otherwise it can
     # raise AppRegistryNotReady when running gis_tests in isolation on some
     # backends (e.g. PostGIS).
     gis_enabled = connection.features.gis_enabled
@@ -279,7 +279,7 @@ def get_installed():
     return [app_config.name for app_config in apps.get_app_configs()]
 
 
-# This function should be called only after calling paradoxdjango.setup(),
+# This function should be called only after calling django.setup(),
 # since it calls connection.features.gis_enabled.
 def get_apps_to_install(test_modules):
     for test_module in test_modules:
@@ -290,7 +290,7 @@ def get_apps_to_install(test_modules):
     # Add contrib.gis to INSTALLED_APPS if needed (rather than requiring
     # @override_settings(INSTALLED_APPS=...) on all test cases.
     if connection.features.gis_enabled:
-        yield "paradoxdjango.contrib.gis"
+        yield "django.contrib.gis"
 
 
 def setup_run_tests(verbosity, start_at, start_after, test_labels=None):
@@ -381,7 +381,7 @@ def django_tests(
 
     if verbosity >= 1:
         msg = "Testing against Django installed in '%s'" % os.path.dirname(
-            paradoxdjango.__file__
+            django.__file__
         )
         if max_parallel > 1:
             msg += " with up to %d processes" % max_parallel
@@ -390,10 +390,10 @@ def django_tests(
     test_labels, state = setup_run_tests(verbosity, start_at, start_after, test_labels)
     # Run the test suite, including the extra validation tests.
     if not hasattr(settings, "TEST_RUNNER"):
-        settings.TEST_RUNNER = "paradoxdjango.test.runner.DiscoverRunner"
+        settings.TEST_RUNNER = "django.test.runner.DiscoverRunner"
 
     if parallel in {0, "auto"}:
-        # This doesn't work before paradoxdjango.setup() on some databases.
+        # This doesn't work before django.setup() on some databases.
         if all(conn.features.can_clone_databases for conn in connections.all()):
             parallel = max_parallel
         else:
