@@ -1,4 +1,4 @@
-from paradoxdjango.test import override_settings
+from django.test import override_settings
 
 from .cases import StaticFilesTestCase
 
