@@ -1,5 +1,5 @@
-from paradoxdjango.test import SimpleTestCase
-from paradoxdjango.test.client import FakePayload
+from django.test import SimpleTestCase
+from django.test.client import FakePayload
 
 
 class FakePayloadTests(SimpleTestCase):
