@@ -7,10 +7,10 @@ from contextlib import contextmanager
 from importlib import import_module
 from unittest import TestSuite, TextTestRunner, defaultTestLoader, mock
 
-from paradoxdjango.db import connections
-from paradoxdjango.test import SimpleTestCase
-from paradoxdjango.test.runner import DiscoverRunner, get_max_test_processes
-from paradoxdjango.test.utils import (
+from django.db import connections
+from django.test import SimpleTestCase
+from django.test.runner import DiscoverRunner, get_max_test_processes
+from django.test.utils import (
     NullTimeKeeper,
     TimeKeeper,
     captured_stderr,
