@@ -2,25 +2,25 @@ import gettext
 import json
 from os import path
 
-from paradoxdjango.conf import settings
-from paradoxdjango.test import (
+from django.conf import settings
+from django.test import (
     RequestFactory,
     SimpleTestCase,
     TestCase,
     modify_settings,
     override_settings,
 )
-from paradoxdjango.test.selenium import SeleniumTestCase
-from paradoxdjango.urls import reverse
-from paradoxdjango.utils.translation import get_language, override
-from paradoxdjango.views.i18n import JavaScriptCatalog, get_formats
+from django.test.selenium import SeleniumTestCase
+from django.urls import reverse
+from django.utils.translation import get_language, override
+from django.views.i18n import JavaScriptCatalog, get_formats
 
 from ..urls import locale_dir
 
 
 @override_settings(ROOT_URLCONF="view_tests.urls")
 class SetLanguageTests(TestCase):
-    """Test the paradoxdjango.views.i18n.set_language view."""
+    """Test the django.views.i18n.set_language view."""
 
     def _get_inactive_language_code(self):
         """Return language code for a language which is not activated."""
@@ -179,7 +179,7 @@ class SetLanguageTests(TestCase):
         # we force saving language to a cookie rather than a session
         # by excluding session middleware and those which do require it
         test_settings = {
-            "MIDDLEWARE": ["paradoxdjango.middleware.common.CommonMiddleware"],
+            "MIDDLEWARE": ["django.middleware.common.CommonMiddleware"],
             "LANGUAGE_COOKIE_NAME": "mylanguage",
             "LANGUAGE_COOKIE_AGE": 3600 * 7 * 2,
             "LANGUAGE_COOKIE_DOMAIN": ".example.com",
@@ -222,7 +222,7 @@ class SetLanguageTests(TestCase):
 
     @modify_settings(
         MIDDLEWARE={
-            "append": "paradoxdjango.middleware.locale.LocaleMiddleware",
+            "append": "django.middleware.locale.LocaleMiddleware",
         }
     )
     def test_lang_from_translated_i18n_pattern(self):
@@ -246,7 +246,7 @@ class SetLanguageTests(TestCase):
 
 @override_settings(ROOT_URLCONF="view_tests.urls")
 class I18NViewTests(SimpleTestCase):
-    """Test paradoxdjango.views.i18n views other than set_language."""
+    """Test django.views.i18n views other than set_language."""
 
     @override_settings(LANGUAGE_CODE="de")
     def test_get_formats(self):
@@ -282,7 +282,7 @@ class I18NViewTests(SimpleTestCase):
         # default plural function
         self.assertContains(
             response,
-            "paradoxdjango.pluralidx = function(count) { return (count == 1) ? 0 : 1; };",
+            "django.pluralidx = function(count) { return (count == 1) ? 0 : 1; };",
         )
         self.assertNotContains(response, "var newcatalog =")
 
@@ -490,9 +490,9 @@ class I18nSeleniumTests(SeleniumTestCase):
 
     # The test cases use fixtures & translations from these apps.
     available_apps = [
-        "paradoxdjango.contrib.admin",
-        "paradoxdjango.contrib.auth",
-        "paradoxdjango.contrib.contenttypes",
+        "django.contrib.admin",
+        "django.contrib.auth",
+        "django.contrib.contenttypes",
         "view_tests",
     ]
 
